@@ -5,22 +5,13 @@
 #include <QStyle>
 #include <QApplication>
 #include <QFontDatabase>
+#include <QStyleHints>
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <MauiMan3/thememanager.h>
-#include <MauiMan3/backgroundmanager.h>
-#include <MauiMan3/accessibilitymanager.h>
-#else
 #include <MauiMan4/thememanager.h>
 #include <MauiMan4/backgroundmanager.h>
 #include <MauiMan4/accessibilitymanager.h>
-#endif
 
-#ifdef Q_OS_ANDROID
-#include "mauiandroid.h"
-#endif
-
-Style *Style::m_instance = nullptr;
+Q_GLOBAL_STATIC(Style, styleInstance)
 
 void Style::styleChanged()
 {
@@ -53,13 +44,7 @@ Style::Style(QObject *parent) : QObject(parent)
   ,m_themeSettings( new MauiMan::ThemeManager(this))
   ,m_backgroundSettings( new MauiMan::BackgroundManager(this))
   ,m_accessibilitySettings( new MauiMan::AccessibilityManager(this))
-  {
-    connect(qApp, &QCoreApplication::aboutToQuit, []()
-    {
-        delete m_instance;
-        m_instance = nullptr;
-    });
-
+{
     connect(qGuiApp, &QGuiApplication::fontChanged, [this](const QFont &font)
     {
         m_defaultFont = font;
@@ -69,9 +54,31 @@ Style::Style(QObject *parent) : QObject(parent)
         Q_EMIT fontSizesChanged();
         Q_EMIT h1FontChanged();
         Q_EMIT h2FontChanged();
-        Q_EMIT 
+        Q_EMIT monospacedFontChanged();
     });
 
+    connect(QGuiApplication::styleHints(), &QStyleHints::colorSchemeChanged, [this](Qt::ColorScheme type)
+    {
+        qDebug() << "Color schem style type changed<<"<< type;
+        if(m_styleType_blocked)
+            return;
+        
+        switch(type)
+        {
+        case Qt::ColorScheme::Unknown:
+            m_styleType = static_cast<Style::StyleType>(m_themeSettings->styleType());
+            break;
+        case Qt::ColorScheme::Light:
+            m_styleType = Style::StyleType::Light;
+            break;
+        case Qt::ColorScheme::Dark:
+            m_styleType = Style::StyleType::Dark;
+            break;
+        }
+
+        Q_EMIT styleTypeChanged(m_styleType);
+    });
+    
     connect(m_themeSettings, &MauiMan::ThemeManager::styleTypeChanged, [this](int type)
     {
         if(m_styleType_blocked)
@@ -80,7 +87,7 @@ Style::Style(QObject *parent) : QObject(parent)
         m_styleType = static_cast<Style::StyleType>(type);
         Q_EMIT styleTypeChanged(m_styleType);
     });
-
+    
     connect(m_themeSettings, &MauiMan::ThemeManager::accentColorChanged, [this](QString color)
     {
         m_accentColor = color;
@@ -138,30 +145,30 @@ Style::Style(QObject *parent) : QObject(parent)
     
     connect(m_accessibilitySettings, &MauiMan::AccessibilityManager::scrollBarPolicyChanged, [this](uint state)
     {
-     qDebug() << "SCROLBAR POLICY CHANGED" << state;
-    Q_EMIT scrollBarPolicyChanged(state);
+        qDebug() << "SCROLBAR POLICY CHANGED" << state;
+        Q_EMIT scrollBarPolicyChanged(state);
     });
 
-   if(MauiManUtils::isMauiSession())
-   {
+    if(MauiManUtils::isMauiSession())
+    {
         connect(m_themeSettings, &MauiMan::ThemeManager::iconThemeChanged, [this](QString name)
         {
             qDebug() << "Ask to change the icon theme";
             m_currentIconTheme = name;
             Q_EMIT currentIconThemeChanged(m_currentIconTheme);
         });
-   }else
-   {
-//        //to be able to check and icon theme change rely on the style being reset, this not even works on Plasma, so do we need it?
-//       QStyle *style = qApp->style();
-//       if (style)
-//       {
-//           connect(style, &QObject::destroyed, this, &Style::styleChanged);
-//       }
-}
+    }else
+    {
+        //        //to be able to check and icon theme change rely on the style being reset, this not even works on Plasma, so do we need it?
+        //       QStyle *style = qApp->style();
+        //       if (style)
+        //       {
+        //           connect(style, &QObject::destroyed, this, &Style::styleChanged);
+        //       }
+    }
 
     m_defaultFont = qGuiApp->font();
- m_monospacedFont = QFontDatabase::systemFont(QFontDatabase::FixedFont);
+    m_monospacedFont = QFontDatabase::systemFont(QFontDatabase::FixedFont);
     setFontSizes();
 
     m_radiusV = m_themeSettings->borderRadius();
@@ -174,12 +181,28 @@ Style::Style(QObject *parent) : QObject(parent)
 
     m_currentIconTheme = QIcon::themeName();
 
-#ifdef Q_OS_ANDROID
-    MAUIAndroid android;
-    m_styleType = android.darkModeEnabled() ? StyleType::Dark : StyleType::Light;
-#else
-    m_styleType = static_cast<Style::StyleType>(m_themeSettings->styleType());
-#endif
+    //TODO Use new Qt6 StyelHint properties for this
+
+    //For Maui Session we want to use MauiMan
+    if(!MauiManUtils::isMauiSession())
+    {
+        switch(QGuiApplication::styleHints()->colorScheme())
+        {
+        case Qt::ColorScheme::Unknown:
+            m_styleType = static_cast<Style::StyleType>(m_themeSettings->styleType());
+            break;
+        case Qt::ColorScheme::Light:
+            m_styleType = Style::StyleType::Light;
+            break;
+        case Qt::ColorScheme::Dark:
+            m_styleType = Style::StyleType::Dark;
+            break;
+        }
+    }
+    else
+    {
+        m_styleType = static_cast<Style::StyleType>(m_themeSettings->styleType());
+    }
 
     m_adaptiveColorSchemeSource = QUrl::fromUserInput(m_backgroundSettings->wallpaperSource()).toLocalFile();
     m_enableEffects = m_themeSettings->enableEffects();
@@ -189,15 +212,15 @@ void Style::setFontSizes()
 {
     qDebug() << m_defaultFont << m_defaultFont.pointSize();
 
-    m_defaultFontSize = m_defaultFont.pointSize ();
+    m_defaultFontSize = m_defaultFont.pointSize () > 0 ? m_defaultFont.pointSize () : m_defaultFont.pixelSize();
 
-    m_fontSizes->m_tiny = m_defaultFont.pointSize ()-2;
-    m_fontSizes->m_small = m_defaultFont.pointSize ()-1;
-    m_fontSizes->m_medium = m_defaultFont.pointSize ();
-    m_fontSizes->m_big = m_defaultFont.pointSize ()+1;
-    m_fontSizes->m_large = m_defaultFont.pointSize ()+2;
-    m_fontSizes->m_huge = m_defaultFont.pointSize ()+3;
-    m_fontSizes->m_enormous = m_defaultFont.pointSize ()+4;
+    m_fontSizes->m_tiny = m_defaultFontSize-2;
+    m_fontSizes->m_small = m_defaultFontSize-1;
+    m_fontSizes->m_medium = m_defaultFontSize;
+    m_fontSizes->m_big = m_defaultFontSize+1;
+    m_fontSizes->m_large = m_defaultFontSize+2;
+    m_fontSizes->m_huge = m_defaultFontSize+3;
+    m_fontSizes->m_enormous = m_defaultFontSize+4;
 
     m_h1Font.setPointSize(m_fontSizes->m_enormous);
     m_h1Font.setWeight(QFont::Black);
@@ -247,6 +270,11 @@ Style *Style::qmlAttachedProperties(QObject *object)
     return Style::instance();
 }
 
+Style *Style::instance()
+{
+    return styleInstance();
+}
+
 int getClosest(int, int, int);
 
 // Returns element closest to target in arr[]
@@ -436,12 +464,13 @@ bool Style::menusHaveIcons() const
 
 uint Style::scrollBarPolicy() const
 {
-    return m_accessibilitySettings->scrollBarPolicy();
+//    return m_accessibilitySettings->scrollBarPolicy();
+    return 2;
 }
 
 bool Style::playSounds() const
 {
-    return m_accessibilitySettings->playSounds();    
+    return m_accessibilitySettings->playSounds();
 }
 
 
