@@ -31,6 +31,8 @@
 #include <QUrl>
 
 #include <android/bitmap.h>
+
+#include <QtCore/private/qandroidextras_p.h>
 // WindowManager.LayoutParams
 #define FLAG_TRANSLUCENT_STATUS 0x04000000
 #define FLAG_DRAWS_SYSTEM_BAR_BACKGROUNDS 0x80000000
@@ -57,18 +59,19 @@ MAUIAndroid::MAUIAndroid(QObject *parent)
     : AbstractPlatform(parent)
 {
     m_instance = this;
-//    connect(qApp, &QCoreApplication::aboutToQuit, []()
-//    {
-//        qDebug() << "Lets remove MauiApp singleton instance";
-//        delete m_instance;
-//        m_instance = nullptr;
-//    });
+    //    connect(qApp, &QCoreApplication::aboutToQuit, []()
+    //    {
+    //        qDebug() << "Lets remove MauiApp singleton instance";
+    //        delete m_instance;
+    //        m_instance = nullptr;
+    //    });
 
 }
 
-static QAndroidJniObject getAndroidWindow()
+static QJniObject getAndroidWindow()
 {
-    QAndroidJniObject window = QtAndroid::androidActivity().callObjectMethod("getWindow", "()Landroid/view/Window;");
+    QJniObject activity = QNativeInterface::QAndroidApplication::context();
+    auto window = activity.callObjectMethod("getWindow", "()Landroid/view/Window;");
     window.callMethod<void>("addFlags", "(I)V", FLAG_DRAWS_SYSTEM_BAR_BACKGROUNDS);
     window.callMethod<void>("clearFlags", "(I)V", FLAG_TRANSLUCENT_STATUS);
     return window;
@@ -76,12 +79,12 @@ static QAndroidJniObject getAndroidWindow()
 
 void MAUIAndroid::statusbarColor(const QString &bg, const bool &light)
 {
-    if (QtAndroid::androidSdkVersion() <= 23)
+    if (QNativeInterface::QAndroidApplication::sdkVersion() <= 23)
         return;
 
-    QtAndroid::runOnAndroidThread([=]() {
-        QAndroidJniObject window = getAndroidWindow();
-        QAndroidJniObject view = window.callObjectMethod("getDecorView", "()Landroid/view/View;");
+    QNativeInterface::QAndroidApplication::runOnAndroidMainThread([=]() {
+        QJniObject window = getAndroidWindow();
+        QJniObject view = window.callObjectMethod("getDecorView", "()Landroid/view/View;");
         int visibility = view.callMethod<int>("getSystemUiVisibility", "()I");
         if (light)
             visibility |= SYSTEM_UI_FLAG_LIGHT_STATUS_BAR;
@@ -94,12 +97,12 @@ void MAUIAndroid::statusbarColor(const QString &bg, const bool &light)
 
 void MAUIAndroid::navBarColor(const QString &bg, const bool &light)
 {
-    if (QtAndroid::androidSdkVersion() <= 23)
+    if (QNativeInterface::QAndroidApplication::sdkVersion() <= 23)
         return;
 
-    QtAndroid::runOnAndroidThread([=]() {
-        QAndroidJniObject window = getAndroidWindow();
-        QAndroidJniObject view = window.callObjectMethod("getDecorView", "()Landroid/view/View;");
+    QNativeInterface::QAndroidApplication::runOnAndroidMainThread([=]() {
+        QJniObject window = getAndroidWindow();
+        QJniObject view = window.callObjectMethod("getDecorView", "()Landroid/view/View;");
         int visibility = view.callMethod<int>("getSystemUiVisibility", "()I");
         if (light)
             visibility |= SYSTEM_UI_FLAG_LIGHT_NAVIGATION_BAR;
@@ -112,8 +115,8 @@ void MAUIAndroid::navBarColor(const QString &bg, const bool &light)
 
 void MAUIAndroid::shareFiles(const QList<QUrl> &urls)
 {
-    QAndroidJniEnvironment _env;
-    QAndroidJniObject activity = QAndroidJniObject::callStaticObjectMethod("org/qtproject/qt5/android/QtNative", "activity", "()Landroid/app/Activity;"); // activity is valid
+    QJniEnvironment _env;
+    QJniObject activity = QJniObject::callStaticObjectMethod("org/qtproject/qt/android/QtNative", "activity", "()Landroid/app/Activity;"); // activity is valid
     if (_env->ExceptionCheck()) {
         _env->ExceptionClear();
         throw InterfaceConnFailedException();
@@ -124,7 +127,7 @@ void MAUIAndroid::shareFiles(const QList<QUrl> &urls)
 
     if (activity.isValid())
     {
-        qDebug() << "trying to share dialog << valid";
+        qDebug() << "trying to share dialog << valid" << QString("%1.provider").arg(qApp->organizationDomain()) ;
 
         QMimeDatabase mimedb;
         QString mimeType = mimedb.mimeTypeForFile(urls.first().toLocalFile()).name();
@@ -134,16 +137,16 @@ void MAUIAndroid::shareFiles(const QList<QUrl> &urls)
         int index = -1;
         for(auto url : urls)
         {
-               _env->SetObjectArrayElement(stringArray, ++index, QAndroidJniObject::fromString(url.toLocalFile()).object<jstring>());
-           }
+            _env->SetObjectArrayElement(stringArray, ++index, QJniObject::fromString(url.toLocalFile()).object<jstring>());
+        }
 
-        QAndroidJniObject::callStaticMethod<void>("com/kde/maui/tools/SendIntent",
-                                                  "share",
-                                                  "(Landroid/app/Activity;[Ljava/lang/String;Ljava/lang/String;Ljava/lang/String;)V",
-                                                  activity.object<jobject>(),
-                                                   QAndroidJniObject::fromLocalRef(stringArray).object<jobjectArray>(),
-                                                  QAndroidJniObject::fromString(mimeType).object<jstring>(),
-                                                  QAndroidJniObject::fromString(QString("%1.fileprovider").arg(qApp->organizationDomain())).object<jstring>());
+        QJniObject::callStaticMethod<void>("com/kde/maui/tools/SendIntent",
+                                           "share",
+                                           "(Landroid/app/Activity;[Ljava/lang/String;Ljava/lang/String;Ljava/lang/String;)V",
+                                           activity.object<jobject>(),
+                                           QJniObject::fromLocalRef(stringArray).object<jobjectArray>(),
+                                           QJniObject::fromString(mimeType).object<jstring>(),
+                                           QJniObject::fromString(QString("%1.provider").arg(qApp->organizationDomain())).object<jstring>());
 
         if (_env->ExceptionCheck())
         {
@@ -160,14 +163,14 @@ void MAUIAndroid::shareFiles(const QList<QUrl> &urls)
 void MAUIAndroid::shareText(const QString &text)
 {
     qDebug() << "trying to share text";
-    QAndroidJniEnvironment _env;
-    QAndroidJniObject activity = QAndroidJniObject::callStaticObjectMethod("org/qtproject/qt5/android/QtNative", "activity", "()Landroid/app/Activity;"); // activity is valid
+    QJniEnvironment _env;
+    QJniObject activity = QJniObject::callStaticObjectMethod("org/qtproject/qt/android/QtNative", "activity", "()Landroid/app/Activity;"); // activity is valid
     if (_env->ExceptionCheck()) {
         _env->ExceptionClear();
         throw InterfaceConnFailedException();
     }
     if (activity.isValid()) {
-        QAndroidJniObject::callStaticMethod<void>("com/kde/maui/tools/SendIntent", "sendText", "(Landroid/app/Activity;Ljava/lang/String;)V", activity.object<jobject>(), QAndroidJniObject::fromString(text).object<jstring>());
+        QJniObject::callStaticMethod<void>("com/kde/maui/tools/SendIntent", "sendText", "(Landroid/app/Activity;Ljava/lang/String;)V", activity.object<jobject>(), QJniObject::fromString(text).object<jstring>());
 
         if (_env->ExceptionCheck()) {
             _env->ExceptionClear();
@@ -180,14 +183,14 @@ void MAUIAndroid::shareText(const QString &text)
 void MAUIAndroid::shareLink(const QString &link)
 {
     qDebug() << "trying to share link";
-    QAndroidJniEnvironment _env;
-    QAndroidJniObject activity = QAndroidJniObject::callStaticObjectMethod("org/qtproject/qt5/android/QtNative", "activity", "()Landroid/app/Activity;"); // activity is valid
+    QJniEnvironment _env;
+    QJniObject activity = QJniObject::callStaticObjectMethod("org/qtproject/qt/android/QtNative", "activity", "()Landroid/app/Activity;"); // activity is valid
     if (_env->ExceptionCheck()) {
         _env->ExceptionClear();
         throw InterfaceConnFailedException();
     }
     if (activity.isValid()) {
-        QAndroidJniObject::callStaticMethod<void>("com/kde/maui/tools/SendIntent", "sendUrl", "(Landroid/app/Activity;Ljava/lang/String;)V", activity.object<jobject>(), QAndroidJniObject::fromString(link).object<jstring>());
+        QJniObject::callStaticMethod<void>("com/kde/maui/tools/SendIntent", "sendUrl", "(Landroid/app/Activity;Ljava/lang/String;)V", activity.object<jobject>(), QJniObject::fromString(link).object<jstring>());
 
         if (_env->ExceptionCheck()) {
             _env->ExceptionClear();
@@ -200,19 +203,19 @@ void MAUIAndroid::shareLink(const QString &link)
 void MAUIAndroid::openUrl(const QUrl &url)
 {
     qDebug() << "trying to open file with";
-    QAndroidJniEnvironment _env;
-    QAndroidJniObject activity = QAndroidJniObject::callStaticObjectMethod("org/qtproject/qt5/android/QtNative", "activity", "()Landroid/app/Activity;"); // activity is valid
+    QJniEnvironment _env;
+    QJniObject activity = QJniObject::callStaticObjectMethod("org/qtproject/qt/android/QtNative", "activity", "()Landroid/app/Activity;"); // activity is valid
     if (_env->ExceptionCheck()) {
         _env->ExceptionClear();
         throw InterfaceConnFailedException();
     }
     if (activity.isValid()) {
-        QAndroidJniObject::callStaticMethod<void>("com/kde/maui/tools/SendIntent",
-                                                  "openUrl",
-                                                  "(Landroid/app/Activity;Ljava/lang/String;Ljava/lang/String;)V",
-                                                  activity.object<jobject>(),
-                                                  QAndroidJniObject::fromString(url.toLocalFile()).object<jstring>(),
-                                                  QAndroidJniObject::fromString(QString("%1.fileprovider").arg(qApp->organizationDomain())).object<jstring>());
+        QJniObject::callStaticMethod<void>("com/kde/maui/tools/SendIntent",
+                                           "openUrl",
+                                           "(Landroid/app/Activity;Ljava/lang/String;Ljava/lang/String;)V",
+                                           activity.object<jobject>(),
+                                           QJniObject::fromString(url.toLocalFile()).object<jstring>(),
+                                           QJniObject::fromString(QString("%1.fileprovider").arg(qApp->organizationDomain())).object<jstring>());
 
         if (_env->ExceptionCheck()) {
             _env->ExceptionClear();
@@ -224,8 +227,8 @@ void MAUIAndroid::openUrl(const QUrl &url)
 
 QString MAUIAndroid::homePath()
 {
-    QAndroidJniObject mediaDir = QAndroidJniObject::callStaticObjectMethod("android/os/Environment", "getExternalStorageDirectory", "()Ljava/io/File;");
-    QAndroidJniObject mediaPath = mediaDir.callObjectMethod("getAbsolutePath", "()Ljava/lang/String;");
+    QJniObject mediaDir = QJniObject::callStaticObjectMethod("android/os/Environment", "getExternalStorageDirectory", "()Ljava/io/File;");
+    QJniObject mediaPath = mediaDir.callObjectMethod("getAbsolutePath", "()Ljava/lang/String;");
 
     return mediaPath.toString();
 }
@@ -234,22 +237,22 @@ QStringList MAUIAndroid::sdDirs()
 {
     QStringList res;
 
-//    QAndroidJniObject mediaDir = QAndroidJniObject::callStaticObjectMethod("com/kde/maui/tools/SDCard", "findSdCardPath", "(Landroid/content/Context;)Ljava/io/File;", QtAndroid::androidActivity().object<jobject>());
+    //    QJniObject mediaDir = QJniObject::callStaticObjectMethod("com/kde/maui/tools/SDCard", "findSdCardPath", "(Landroid/content/Context;)Ljava/io/File;", QtAndroid::androidActivity().object<jobject>());
 
-//    if (mediaDir == NULL)
-//        return res;
+    //    if (mediaDir == NULL)
+    //        return res;
 
-//    QAndroidJniObject mediaPath = mediaDir.callObjectMethod("getAbsolutePath", "()Ljava/lang/String;");
-//    QString dataAbsPath = mediaPath.toString();
+    //    QJniObject mediaPath = mediaDir.callObjectMethod("getAbsolutePath", "()Ljava/lang/String;");
+    //    QString dataAbsPath = mediaPath.toString();
 
-//    res << QUrl::fromLocalFile(dataAbsPath).toString();
+    //    res << QUrl::fromLocalFile(dataAbsPath).toString();
     return res;
 }
 
-// void MAUIAndroid::handleActivityResult(int receiverRequestCode, int resultCode, const QAndroidJniObject &data)
+// void MAUIAndroid::handleActivityResult(int receiverRequestCode, int resultCode, const QJniObject &data)
 //{
 //    qDebug() << "ACTIVITY RESULTS";
-//    jint RESULT_OK = QAndroidJniObject::getStaticField<jint>("android/app/Activity", "RESULT_OK");
+//    jint RESULT_OK = QJniObject::getStaticField<jint>("android/app/Activity", "RESULT_OK");
 
 //    if (receiverRequestCode == 42 && resultCode == RESULT_OK) {
 //        QString url = data.callObjectMethod("getData", "()Landroid/net/Uri;").callObjectMethod("getPath", "()Ljava/lang/String;").toString();
@@ -259,14 +262,14 @@ QStringList MAUIAndroid::sdDirs()
 
 void MAUIAndroid::fileChooser()
 {
-    QAndroidJniEnvironment _env;
-    QAndroidJniObject activity = QAndroidJniObject::callStaticObjectMethod("org/qtproject/qt5/android/QtNative", "activity", "()Landroid/app/Activity;"); // activity is valid
+    QJniEnvironment _env;
+    QJniObject activity = QJniObject::callStaticObjectMethod("org/qtproject/qt/android/QtNative", "activity", "()Landroid/app/Activity;"); // activity is valid
     if (_env->ExceptionCheck()) {
         _env->ExceptionClear();
         throw InterfaceConnFailedException();
     }
     if (activity.isValid()) {
-        QAndroidJniObject::callStaticMethod<void>("com/example/android/tools/SendIntent", "fileChooser", "(Landroid/app/Activity;)V", activity.object<jobject>());
+        QJniObject::callStaticMethod<void>("com/example/android/tools/SendIntent", "fileChooser", "(Landroid/app/Activity;)V", activity.object<jobject>());
         if (_env->ExceptionCheck()) {
             _env->ExceptionClear();
             throw InterfaceConnFailedException();
@@ -275,13 +278,13 @@ void MAUIAndroid::fileChooser()
         throw InterfaceConnFailedException();
 }
 
-QVariantList MAUIAndroid::transform(const QAndroidJniObject &obj)
+QVariantList MAUIAndroid::transform(const QJniObject &obj)
 {
     QVariantList res;
     const auto size = obj.callMethod<jint>("size", "()I");
 
     for (auto i = 0; i < size; i++) {
-        QAndroidJniObject hashObj = obj.callObjectMethod("get", "(I)Ljava/lang/Object;", i);
+        QJniObject hashObj = obj.callObjectMethod("get", "(I)Ljava/lang/Object;", i);
         res << createVariantMap(hashObj.object<jobject>());
     }
 
@@ -292,19 +295,19 @@ QVariantMap MAUIAndroid::createVariantMap(jobject data)
 {
     QVariantMap res;
 
-    QAndroidJniEnvironment env;
+    QJniEnvironment env;
     /* Reference : https://community.oracle.com/thread/1549999 */
 
-    // Get the HashMap Class
+           // Get the HashMap Class
     jclass jclass_of_hashmap = (env)->GetObjectClass(data);
 
-    // Get link to Method "entrySet"
+           // Get link to Method "entrySet"
     jmethodID entrySetMethod = (env)->GetMethodID(jclass_of_hashmap, "entrySet", "()Ljava/util/Set;");
 
-    // Invoke the "entrySet" method on the HashMap object
+           // Invoke the "entrySet" method on the HashMap object
     jobject jobject_of_entryset = env->CallObjectMethod(data, entrySetMethod);
 
-    // Get the Set Class
+           // Get the Set Class
     jclass jclass_of_set = (env)->FindClass("java/util/Set"); // Problem during compilation !!!!!
 
     if (jclass_of_set == 0) {
@@ -312,25 +315,25 @@ QVariantMap MAUIAndroid::createVariantMap(jobject data)
         return res;
     }
 
-    // Get link to Method "iterator"
+           // Get link to Method "iterator"
     jmethodID iteratorMethod = env->GetMethodID(jclass_of_set, "iterator", "()Ljava/util/Iterator;");
 
-    // Invoke the "iterator" method on the jobject_of_entryset variable of type Set
+           // Invoke the "iterator" method on the jobject_of_entryset variable of type Set
     jobject jobject_of_iterator = env->CallObjectMethod(jobject_of_entryset, iteratorMethod);
 
-    // Get the "Iterator" class
+           // Get the "Iterator" class
     jclass jclass_of_iterator = (env)->FindClass("java/util/Iterator");
 
-    // Get link to Method "hasNext"
+           // Get link to Method "hasNext"
     jmethodID hasNextMethod = env->GetMethodID(jclass_of_iterator, "hasNext", "()Z");
 
     jmethodID nextMethod = env->GetMethodID(jclass_of_iterator, "next", "()Ljava/lang/Object;");
 
     while (env->CallBooleanMethod(jobject_of_iterator, hasNextMethod)) {
         jobject jEntry = env->CallObjectMethod(jobject_of_iterator, nextMethod);
-        QAndroidJniObject entry = QAndroidJniObject(jEntry);
-        QAndroidJniObject key = entry.callObjectMethod("getKey", "()Ljava/lang/Object;");
-        QAndroidJniObject value = entry.callObjectMethod("getValue", "()Ljava/lang/Object;");
+        QJniObject entry = QJniObject(jEntry);
+        QJniObject key = entry.callObjectMethod("getKey", "()Ljava/lang/Object;");
+        QJniObject value = entry.callObjectMethod("getValue", "()Ljava/lang/Object;");
         QString k = key.toString();
 
         QVariant v = value.toString();
@@ -358,33 +361,13 @@ QVariantMap MAUIAndroid::createVariantMap(jobject data)
     return res;
 }
 
-bool MAUIAndroid::checkRunTimePermissions(const QStringList &permissions)
-{
-    qDebug() << "CHECKIGN PERMISSSIONS";
-
-    for (const auto &permission : permissions) {
-        QtAndroid::PermissionResult r = QtAndroid::checkPermission(permission);
-        if (r == QtAndroid::PermissionResult::Denied) {
-            QtAndroid::requestPermissionsSync({permission});
-            r = QtAndroid::checkPermission(permission);
-            if (r == QtAndroid::PermissionResult::Denied) {
-                qWarning() << "Permission denied";
-                return false;
-            }
-        }
-    }
-
-    qDebug() << "Permissions granted!";
-    return true;
-}
-
 bool MAUIAndroid::hasKeyboard()
 {
-    QAndroidJniObject context = QtAndroid::androidContext().object<jobject>();
+    QJniObject context = QNativeInterface::QAndroidApplication::context().object<jobject>();
 
     if (context.isValid()) {
-        QAndroidJniObject resources = context.callObjectMethod("getResources", "()Landroid/content/res/Resources;");
-        QAndroidJniObject config = resources.callObjectMethod("getConfiguration", "()Landroid/content/res/Configuration;");
+        QJniObject resources = context.callObjectMethod("getResources", "()Landroid/content/res/Resources;");
+        QJniObject config = resources.callObjectMethod("getConfiguration", "()Landroid/content/res/Configuration;");
         int value = config.getField<jint>("keyboard");
         //        QVariant v = value.toString();
         qDebug() << "KEYBOARD" << value;
@@ -400,11 +383,25 @@ bool MAUIAndroid::hasMouse()
     return false;
 }
 
-void MAUIAndroid::handleActivityResult(int receiverRequestCode, int resultCode, const QAndroidJniObject &data)
+bool MAUIAndroid::checkRunTimePermissions(const QStringList &permissions)
+{
+    for (const auto &permission : permissions) {
+        auto r = QtAndroidPrivate::checkPermission(permission).result();
+        if (r == QtAndroidPrivate::Denied)
+        {
+            r = QtAndroidPrivate::requestPermission(permission).result();
+            if (r == QtAndroidPrivate::Denied)
+                return false;
+        }
+    }
+    return true;
+}
+
+void MAUIAndroid::handleActivityResult(int receiverRequestCode, int resultCode, const QJniObject &data)
 {
     qDebug() << "ACTIVITY RESULTS" << receiverRequestCode;
-    emit this->hasKeyboardChanged();
-    jint RESULT_OK = QAndroidJniObject::getStaticField<jint>("android/app/Activity", "RESULT_OK");
+    Q_EMIT this->hasKeyboardChanged();
+    jint RESULT_OK = QJniObject::getStaticField<jint>("android/app/Activity", "RESULT_OK");
 
     if (receiverRequestCode == 42 && resultCode == RESULT_OK) {
         QString url = data.callObjectMethod("getData", "()Landroid/net/Uri;").callObjectMethod("getPath", "()Ljava/lang/String;").toString();
@@ -415,11 +412,11 @@ void MAUIAndroid::handleActivityResult(int receiverRequestCode, int resultCode,
 
 bool MAUIAndroid::darkModeEnabled()
 {
-    jint res = QAndroidJniObject::callStaticMethod<jint>(
+    jint res = QJniObject::callStaticMethod<jint>(
         "com/kde/maui/tools/ConfigActivity",
         "systemStyle",
         "(Landroid/content/Context;)I",
-        QtAndroid::androidActivity().object());
+        QNativeInterface::QAndroidApplication::context().object());
 
     return res == 1;
 }
