@@ -105,7 +105,7 @@ namespace Maui
                 Q_EMIT this->changed();
             }
         });
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+
         connect(qGuiApp, &QGuiApplication::paletteChanged, [this, style](QPalette)
         {
             if(style->styleType() == Style::StyleType::Auto)
@@ -114,16 +114,7 @@ namespace Maui
                 Q_EMIT this->changed();
             }
         });
-#else
-        connect(qGuiApp, &QGuiApplication::paletteChanged, [this, style](QPalette)
-        {
-            if(style->styleType() == Style::StyleType::Auto)
-            {
-                setSystemPaletteColors();
-                Q_EMIT this->changed();
-            }
-        });
-#endif
+
         switch(style->styleType())
         {
             case Style::StyleType::Light:
@@ -243,9 +234,9 @@ namespace Maui
 
         negativeTextColor = QColor{"#dac7cb"};
         negativeBackgroundColor = QColor{"#DA4453"};
-        neutralTextColor = QColor{"#333"};
+        neutralTextColor = QColor{"#fafafa"};
         neutralBackgroundColor = QColor{"#F67400"};
-        positiveTextColor = QColor{"#333"};
+        positiveTextColor = QColor{"#fafafa"};
         positiveBackgroundColor = QColor{"#27AE60"};
 
         tooltipTextColor = QColor{"#fafafa"};
@@ -380,9 +371,9 @@ namespace Maui
 
         negativeTextColor = QColor{"#dac7cb"};
         negativeBackgroundColor = QColor{"#DA4453"};
-        neutralTextColor = QColor{"#333"};
+        neutralTextColor = QColor{"#fafafa"};
         neutralBackgroundColor = QColor{"#F67400"};
-        positiveTextColor = QColor{"#333"};
+        positiveTextColor = QColor{"#fafafa"};
         positiveBackgroundColor = QColor{"#27AE60"};
 
         tooltipTextColor = QColor{"#fafafa"};
@@ -407,6 +398,7 @@ namespace Maui
         backgroundColor = cu.tintWithAlpha(LightColor::backgroundColor, highlightColor, 0.02);
         activeBackgroundColor = highlightColor;
         alternateBackgroundColor = cu.tintWithAlpha(LightColor::alternateBackgroundColor, highlightColor, 0.02);
+
         hoverColor = LightColor::hoverColor;
         focusColor = highlightColor;
 
@@ -449,9 +441,9 @@ namespace Maui
 
         negativeTextColor = QColor{"#dac7cb"};
         negativeBackgroundColor = QColor{"#DA4453"};
-        neutralTextColor = QColor{"#333"};
+        neutralTextColor = QColor{"#fafafa"};
         neutralBackgroundColor = QColor{"#F67400"};
-        positiveTextColor = QColor{"#333"};
+        positiveTextColor = QColor{"#fafafa"};
         positiveBackgroundColor = QColor{"#27AE60"};
 
         tooltipTextColor = QColor{"#fafafa"};
@@ -478,7 +470,8 @@ namespace Maui
 //         backgroundColor = cu.tintWithAlpha(m_imgColors->background(), bgColor, 0.8);
         backgroundColor =  cu.tintWithAlpha(bgColor, highlightColor, 0.03);
         activeBackgroundColor = highlightColor;
-        alternateBackgroundColor = cu.tintWithAlpha(isDark ? DarkColor::alternateBackgroundColor : LightColor::alternateBackgroundColor, highlightColor, 0.03);
+        alternateBackgroundColor = cu.tintWithAlpha(backgroundColor, highlightColor, 0.02);
+
         hoverColor =  cu.tintWithAlpha(isDark ? DarkColor::hoverColor : LightColor::hoverColor, highlightColor, 0.02);
 
         focusColor = highlightColor;
@@ -512,6 +505,8 @@ namespace Maui
         headerTextColor = textColor;
         headerBackgroundColor = cu.tintWithAlpha(bgColor, highlightColor, 0.05);
         headerAlternateBackgroundColor = headerBackgroundColor.darker();
+        headerAlternateBackgroundColor = cu.tintWithAlpha(bgColor, highlightColor, 0.02);
+
         headerHoverColor = headerBackgroundColor.lighter();
         headerFocusColor = highlightColor;
 
@@ -522,9 +517,9 @@ namespace Maui
 
         negativeTextColor = QColor{"#dac7cb"};
         negativeBackgroundColor = QColor{"#DA4453"};
-        neutralTextColor = QColor{"#333"};
+        neutralTextColor = QColor{"#fafafa"};
         neutralBackgroundColor = QColor{"#F67400"};
-        positiveTextColor = QColor{"#333"};
+        positiveTextColor = QColor{"#fafafa"};
         positiveBackgroundColor = QColor{"#27AE60"};
 
         tooltipTextColor = QColor{"#fafafa"};
