@@ -32,11 +32,7 @@
 
 #include "platforms/platform.h"
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <QTouchDevice>
-#else
 #include <QInputDevice>
-#endif
 
 #ifdef Q_OS_ANDROID
 #include <QGuiApplication>
@@ -44,13 +40,8 @@
 #include <QApplication>
 #endif
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <MauiMan3/formfactormanager.h>
-#include <MauiMan3/accessibilitymanager.h>
-#else
 #include <MauiMan4/formfactormanager.h>
 #include <MauiMan4/accessibilitymanager.h>
-#endif
 
 Q_GLOBAL_STATIC(Handy, handyInstance)
 
@@ -82,13 +73,13 @@ connect(m_formFactor, &MauiMan::FormFactorManager::preferredModeChanged, [this](
 
 connect(m_formFactor, &MauiMan::FormFactorManager::hasTouchscreenChanged, [this](bool value)
 {
-    m_isTouch = value;
+    m_isTouch = value || m_formFactor->forceTouchScreen();
     Q_EMIT isTouchChanged();
 });
 
 m_ffactor = static_cast<FFactor>(m_formFactor->preferredMode());
 m_mobile = m_ffactor == FFactor::Phone || m_ffactor == FFactor::Tablet;
-m_isTouch = m_formFactor->hasTouchscreen();
+m_isTouch = m_formFactor->hasTouchscreen() || m_formFactor->forceTouchScreen();
 
     connect(qApp, &QGuiApplication::focusWindowChanged, this, [this](QWindow *win)
     {
