@@ -200,15 +200,9 @@ void Icon::refresh()
     this->polish();
 }
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-void Icon::geometryChanged(const QRectF &newGeometry, const QRectF &oldGeometry)
-{
-    QQuickItem::geometryChanged(newGeometry, oldGeometry);
-#else
 void Icon::geometryChange(const QRectF &newGeometry, const QRectF &oldGeometry)
 {
     QQuickItem::geometryChange(newGeometry, oldGeometry);
-#endif
     if (newGeometry.size() != oldGeometry.size()) {
         polish();
     }
@@ -340,9 +334,8 @@ QImage Icon::findIcon(const QSize &size)
     QString iconSource = m_source.toString();
 
     if (iconSource.startsWith(QLatin1String("image://"))) {
-        const auto multiplier = QCoreApplication::instance()->testAttribute(Qt::AA_UseHighDpiPixmaps)
-            ? (window() ? window()->effectiveDevicePixelRatio() : qGuiApp->devicePixelRatio())
-            : 1;
+        const auto multiplier = (window() ? window()->effectiveDevicePixelRatio() : qGuiApp->devicePixelRatio());
+
         QUrl iconUrl(iconSource);
         QString iconProviderId = iconUrl.host();
         // QUrl path has the  "/" prefix while iconId does not
