@@ -1,6 +1,5 @@
 #include "moduleinfo.h"
 #include "../mauikit_version.h"
-#include <KI18n/KLocalizedString>
 
 QString MauiKitCore::versionString()
 {
@@ -15,7 +14,7 @@ QString MauiKitCore::buildVersion()
 KAboutComponent MauiKitCore::aboutData()
 {
     return KAboutComponent(QStringLiteral("MauiKit Core"),
-                         i18n("Maui convergent controls."),
+                         QStringLiteral("Maui convergent controls."),
                          QStringLiteral(MAUIKIT_VERSION_STRING),
                          QStringLiteral("http://mauikit.org"),
                          KAboutLicense::LicenseKey::LGPL_V3);
@@ -24,7 +23,7 @@ KAboutComponent MauiKitCore::aboutData()
 KAboutComponent MauiKitCore::aboutLuv()
 {
     return KAboutComponent(QStringLiteral("Lüv Icon Theme"),
-                         i18n("Lüv is the spiritual successor to Flattr, a flat but complex icon theme for freedesktop environments."),
+                         QStringLiteral("Lüv is the spiritual successor to Flattr, a flat but complex icon theme for freedesktop environments."),
                          QStringLiteral("1.0"),
                          QStringLiteral("https://github.com/Nitrux/luv-icon-theme"),
                          KAboutLicense::LicenseKey::Artistic);
